@@ -4,7 +4,7 @@ use warnings;
 
 use Test2::IPC;
 
-our $VERSION = '0.000016';
+our $VERSION = '0.000020';
 
 our @CARP_NOT = qw/Test2::Util::HashBase/;
 
@@ -53,7 +53,6 @@ sub init {
         unless $self->{+NAME};
 
     $self->{+SEND_TO} ||= Test2::API::test2_stack()->top;
-    $self->{+TRACE}   ||= Test2::Util::Trace->new(frame => [caller(1)]);
 
     $self->{+STACK} = [@STACK];
     $_->{+_IN_USE}++ for reverse @STACK;
@@ -79,6 +78,10 @@ sub init {
         $self->{+HUB} = $hub;
     }
 
+    $self->{+TRACE} ||= Test2::Util::Trace->new(
+        frame => [caller(1)],
+    );
+
     my $hub = $self->{+HUB};
     $hub->set_ast_ids({}) unless $hub->ast_ids;
     $hub->listen($self->_listener);
@@ -487,8 +490,8 @@ Test2::AsyncSubtest - Object representing an async subtest.
 
 Regular subtests have a limited scope, they start, events are generated, then
 they close and send an L<Test2::Event::Subtest> event. This is a problem if you
-want the subtest to keep recieving events while other events are also being
-generated. This class implements subtests that stay pen until you decide to
+want the subtest to keep receiving events while other events are also being
+generated. This class implements subtests that stay open until you decide to
 close them.
 
 This is mainly useful for tools that start a subtest in one process or thread
@@ -679,7 +682,7 @@ none is directly specified.
 
 This will issue an L<Test2::Event::Skip> instead of a subtest. This will throw
 an exception if any events have been seen, or if state implies events have
-occured.
+occurred.
 
 =back
 
@@ -690,7 +693,7 @@ code in-place just like C<fork()>. It will return a pid in the parent, and an
 L<Scope::Guard> instance in the child. An exception will be thrown if fork
 fails.
 
-It is recomended that you use C<< $ast->run_fork(sub { ... }) >> instead.
+It is recommended that you use C<< $ast->run_fork(sub { ... }) >> instead.
 
 =item $bool = $ast->pending
 
